You can review the cost report by clicking the button below.

Hello {{user_name}}, This is the cost report for '{{workspace_name}}'. - Issue date: {{report_date}} - Issue period: {{report_period}} You can review the cost report by clicking the button below.
View Cost Report
(This link will expire within 24 hours of creation.) Sincerely yours, SpaceONE
Homepage | Blog | Help Center Copyright 2023 © MEGAZONE CLOUD Corp. All Right Reserved.